@@ -6,26 +6,18 @@ Created on Mar 14, 2015
 @contact: andrew@calcbench.com
 """
 
+import dataclasses
 import json
 import logging
 import os
 from datetime import datetime
-from enum import Enum, IntEnum
 from functools import wraps
-from typing import (
-    Callable,
-    Dict,
-    Optional,
-    Sequence,
-    Union,
-)
+from typing import Callable, Dict, Iterable, Sequence, Union
 
 from requests.sessions import Session
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
+from calcbench.api_query_params import APIQueryParams
+
 
 import requests
 
@@ -98,13 +90,6 @@ def _rig_for_testing(domain="localhost:444", suppress_http_warnings=True):
         requests.packages.urllib3.disable_warnings(InsecureRequestWarning)  # type: ignore
 
 
-CentralIndexKey = Union[str, int]
-Ticker = str
-CalcbenchCompanyIdentifier = int
-CompanyIdentifier = Union[Ticker, CentralIndexKey, CalcbenchCompanyIdentifier]
-CompanyIdentifiers = Sequence[CompanyIdentifier]
-
-
 def _add_backoff(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
@@ -124,7 +109,7 @@ def _add_backoff(f):
 
 
 @_add_backoff
-def _json_POST(end_point: str, payload: dict):
+def _json_POST(end_point: str, payload: Union[dict, APIQueryParams]):
     url = _SESSION_STUFF["api_url_base"].format(end_point)
     logger.debug(f"posting to {url}, {payload}")
     start = datetime.now()
@@ -221,27 +206,13 @@ def set_proxies(proxies: Dict[str, str]):
     _SESSION_STUFF["proxies"] = proxies
 
 
-class CompanyIdentifierScheme(str, Enum):
-    Ticker = "ticker"
-    CentralIndexKey = "CIK"
-
-
-class PeriodType(str, Enum):
-    Annual = "annual"
-    Quarterly = "quarterly"
-    Combined = "combined"
-    TrailingTwelveMonths = "TTM"
-
-
-class Period(IntEnum):
-    Annual = 0
-    Q1 = 1
-    Q2 = 2
-    Q3 = 3
-    Q4 = 4
-
-
-PeriodArgument = Optional[Union[Period, Literal[0, 1, 2, 3, 4]]]
+def set_field_values(dataclass, kwargs: dict, date_columns: Iterable[str] = []):
+    names = set([f.name for f in dataclasses.fields(dataclass)])
+    for k, v in kwargs.items():
+        if k in names:
+            if k in date_columns:
+                v = _try_parse_timestamp(v)
+            setattr(dataclass, k, v)
 
 
 def face_statement(
@@ -360,21 +331,3 @@ def document_types():
 def html_diff(html_1, html_2):
     """Diff two pieces of html and return a html diff"""
     return _json_POST("textDiff", {"html1": html_1, "html2": html_2})
-
-
-def press_release_raw(
-    company_identifiers,
-    year,
-    period,
-    match_to_previous_period=False,
-    standardize_beginning_of_period=False,
-):
-    payload = {
-        "companiesParameters": {"companyIdentifiers": list(company_identifiers)},
-        "periodParameters": {"year": year, "period": period},
-        "pageParameters": {
-            "matchToPreviousPeriod": match_to_previous_period,
-            "standardizeBOPPeriods": standardize_beginning_of_period,
-        },
-    }
-    return _json_POST("pressReleaseData", payload)
