@@ -5,11 +5,10 @@ from typing import Iterable, Optional
 import dataclasses
 
 from calcbench.api_client import (
-    CompanyIdentifiers,
-    Period,
     _json_POST,
     _try_parse_timestamp,
 )
+from calcbench.api_query_params import CompanyIdentifiers, Period
 
 
 class FilingType(str, Enum):
@@ -41,7 +40,6 @@ class FilingType(str, Enum):
 class Filing(dict):
     is_xbrl: bool
     is_wire: bool
-    """AKA accession_id"""
     calcbench_id: int
     sec_accession_id: str
     sec_html_url: str
@@ -72,7 +70,7 @@ class Filing(dict):
 
     @property
     def accession_id(self) -> int:
-        """calcbench_id should have been accession_id"""
+        """same as calcbench_id, calcbench_id should have been accession_id"""
         return self.calcbench_id
 
     def __init__(self, **kwargs):
@@ -99,7 +97,7 @@ def filings(
     received_date: date = None,
     start_date: date = None,
     end_date: date = None,
-    filing_types=[],
+    include_press_releases_and_proxies: bool = True,
 ) -> Iterable[Filing]:
     """SEC filings
 
@@ -128,7 +126,7 @@ def filings(
             },
             "pageParameters": {
                 "includeNonXBRL": include_non_xbrl,
-                "filingTypes": filing_types,
+                "includePressReleasesAndProxies": include_press_releases_and_proxies,
             },
             "periodParameters": {
                 "updateDate": received_date and received_date.isoformat(),
